@@ -4,7 +4,7 @@ from abc import ABC, abstractmethod
 class EventSelectionStrategy(ABC):
 
     @abstractmethod
-    def select(self, statements):
+    def select(self, statements, external_events_queue=[]):
         pass
 
     @abstractmethod
